ActivitySelectorConfig class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

ActivitySelectorConfig({required DateTime cutoffTime, Map<String, Object?>? filter, int? minPopularity, List<SortParam>? sort, String? type})
const

Properties

copyWith → $ActivitySelectorConfigCopyWith<ActivitySelectorConfig>
Create a copy of ActivitySelectorConfig with the given fields replaced by the non-null parameter values.
no setterinherited
cutoffTime → DateTime
final
filter → Map<String, Object?>?
final
hashCode → int
The hash code for this object.
no setterinherited
minPopularity → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort → List<SortParam>?
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ActivitySelectorConfig