BookmarkFolderUpdatedEvent class

Inheritance
Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

BookmarkFolderUpdatedEvent({required BookmarkFolderResponse bookmarkFolder, required DateTime createdAt, required Map<String, Object?> custom, DateTime? receivedAt, required String type, UserResponseCommonFields? user})
const

Properties

bookmarkFolder → BookmarkFolderResponse
final
copyWith → $BookmarkFolderUpdatedEventCopyWith<BookmarkFolderUpdatedEvent>
Create a copy of BookmarkFolderUpdatedEvent with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
final
custom → Map<String, Object?>
final
error → Object?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
healthCheckInfo → HealthCheckInfo?
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
receivedAt → DateTime?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → String
final
user → UserResponseCommonFields?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → BookmarkFolderUpdatedEvent