CallParticipant class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

CallParticipant({int? avgResponseTime, DateTime? banExpires, required bool banned, DateTime? createdAt, required Map<String, Object?> custom, DateTime? deactivatedAt, DateTime? deletedAt, required String id, bool? invisible, required DateTime joinedAt, String? language, DateTime? lastActive, DateTime? lastEngagedAt, required bool online, PrivacySettings? privacySettings, DateTime? revokeTokensIssuedBefore, required String role, List<String>? teams, required Map<String, String> teamsRole, DateTime? updatedAt, required String userSessionID})
const

Properties

avgResponseTime → int?
final
banExpires → DateTime?
final
banned → bool
final
copyWith → $CallParticipantCopyWith<CallParticipant>
Create a copy of CallParticipant with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime?
final
custom → Map<String, Object?>
final
deactivatedAt → DateTime?
final
deletedAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
invisible → bool?
final
joinedAt → DateTime
final
language → String?
final
lastActive → DateTime?
final
lastEngagedAt → DateTime?
final
online → bool
final
privacySettings → PrivacySettings?
final
revokeTokensIssuedBefore → DateTime?
final
role → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teams → List<String>?
final
teamsRole → Map<String, String>
final
updatedAt → DateTime?
final
userSessionID → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → CallParticipant