DecayFunctionConfig class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

DecayFunctionConfig({String? base, String? decay, String? direction, String? offset, String? origin, String? scale})
const

Properties

base → String?
final
copyWith → $DecayFunctionConfigCopyWith<DecayFunctionConfig>
Create a copy of DecayFunctionConfig with the given fields replaced by the non-null parameter values.
no setterinherited
decay → String?
final
direction → String?
final
hashCode → int
The hash code for this object.
no setterinherited
offset → String?
final
origin → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → DecayFunctionConfig