EnrichedReaction class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

EnrichedReaction({required String activityId, Map<String, int>? childrenCounts, Map<String, Object?>? data, String? id, required String kind, Map<String, List<EnrichedReaction>>? latestChildren, Map<String, List<EnrichedReaction>>? ownChildren, String? parent, List<String>? targetFeeds, Data? user, required String userId})
const

Properties

activityId → String
final
childrenCounts → Map<String, int>?
final
copyWith → $EnrichedReactionCopyWith<EnrichedReaction>
Create a copy of EnrichedReaction with the given fields replaced by the non-null parameter values.
no setterinherited
data → Map<String, Object?>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
kind → String
final
latestChildren → Map<String, List<EnrichedReaction>>?
final
ownChildren → Map<String, List<EnrichedReaction>>?
final
parent → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetFeeds → List<String>?
final
user → Data?
final
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → EnrichedReaction