Failure class

Represents failed result.

Inheritance

Properties

error → Object
The error associated with the result.
final
hashCode → int
The hash code for this object.
no setterinherited
isFailure → bool
Returns true if this instance represents a failed outcome. In this case isSuccess returns false.
no setterinherited
isSuccess → bool
Returns true if this instance represents a successful outcome. In this case isFailure returns false.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stackTrace associated with the result.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited