HttpClientException class

Inheritance

Constructors

HttpClientException({String? message, Object? error, StackTrace? stackTrace, required int? statusCode, required bool isRequestCancelledError})

Properties

apiError ↔ StreamApiError?
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
isRequestCancelledError → bool
final
message → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
finalinherited
statusCode → int?
final
underlyingError ↔ Object?
latefinalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited