MessageReminder class

Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

MessageReminder({Channel? channel, required String channelCid, required DateTime createdAt, Message? message, required String messageId, DateTime? remindAt, required String taskId, required DateTime updatedAt, User? user, required String userId})
const

Properties

channel → Channel?
final
channelCid → String
final
copyWith → $MessageReminderCopyWith<MessageReminder>
Create a copy of MessageReminder with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
message → Message?
final
messageId → String
final
remindAt → DateTime?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskId → String
final
updatedAt → DateTime
final
user → User?
final
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → MessageReminder