UserResponse class

Available extensions
Annotations
  • @freezed
  • @immutable
  • @JsonSerializable.new()

Constructors

UserResponse({int? avgResponseTime, required bool banned, required List<String> blockedUserIds, required DateTime createdAt, required Map<String, Object?> custom, DateTime? deactivatedAt, DateTime? deletedAt, required String id, String? image, required String language, DateTime? lastActive, String? name, required bool online, DateTime? revokeTokensIssuedBefore, required String role, required List<String> teams, Map<String, String>? teamsRole, required DateTime updatedAt})
const

Properties

avgResponseTime → int?
final
banned → bool
final
blockedUserIds → List<String>
final
copyWith → $UserResponseCopyWith<UserResponse>
Create a copy of UserResponse with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → DateTime
final
custom → Map<String, Object?>
final
deactivatedAt → DateTime?
final
deletedAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
image → String?
final
language → String
final
lastActive → DateTime?
final
name → String?
final
online → bool
final
revokeTokensIssuedBefore → DateTime?
final
role → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teams → List<String>
final
teamsRole → Map<String, String>?
final
updatedAt → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toModel() → UserData

Available on UserResponse, provided by the UserResponseMapper extension

Converts this API user response to a domain UserData instance.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → UserResponse